Index: trunk/ippTools/src/warptool.c
===================================================================
--- trunk/ippTools/src/warptool.c	(revision 31719)
+++ trunk/ippTools/src/warptool.c	(revision 31955)
@@ -1382,4 +1382,5 @@
     pxAddLabelSearchArgs (config, where, "-data_group",   "warpRun.data_group", "LIKE");
 
+    PXOPT_LOOKUP_BOOL(pstamp_order, config->args, "-pstamp_order", false);
     PXOPT_LOOKUP_BOOL(all, config->args, "-all", false);
 
@@ -1423,4 +1424,10 @@
     }
     psFree(where);
+
+    if (pstamp_order) {
+        // put runs in order of exposure id with newest warp Runs first
+        // The postage stamp parser depends on this behavior
+        psStringAppend(&query, "\nORDER by exp_id, warp_id DESC");
+    }
 
     // treat limit == 0 as "no limit"
@@ -2467,9 +2474,8 @@
 
     if (pstamp_order) {
         // put runs in order of exposure id with newest chip Runs first
         // The postage stamp parser depends on this behavior
         psStringAppend(&query, "\nORDER by exp_id, warp_id DESC");
     }
-
 
     // treat limit == 0 as "no limit"
@@ -2467,9 +2474,8 @@
 
     if (pstamp_order) {
-        // put runs in order of exposure id with newest chip Runs first
+        // put runs in order of exposure id with newest warp Runs first
         // The postage stamp parser depends on this behavior
         psStringAppend(&query, "\nORDER by exp_id, warp_id DESC");
